@@ -12,6 +12,8 @@ pub enum Clause {
     And(VarIdx, VarIdx, VarIdx),
     // True if a or b = c
     Or(VarIdx, VarIdx, VarIdx),
+    // True if a and not b = c.
+    AndNot(VarIdx, VarIdx, VarIdx),
     // True if a = b
     Equal(VarIdx, VarIdx),
     // True if a != b
@@ -35,7 +37,7 @@ pub enum Clause {
 impl Clause {
     pub fn has_duplicate_indices(&self) -> bool {
         match self {
-            And(a, b, c) | Or(a, b, c) => a == b || b == c || c == a,
+            And(a, b, c) | Or(a, b, c) | AndNot(a, b, c) => a == b || b == c || c == a,
             Equal(a, b) | Not(a, b) => a == b,
             FixNeg(_) | FixPos(_) => false,
             EvenXor(vars) | OddXor(vars) | NotAllNeg(vars) | NotAllPos(vars) | AtLeast(_, vars) => {
@@ -47,7 +49,7 @@ impl Clause {
     pub fn max_index(&self) -> VarIdx {
         use std::cmp::max;
         match self {
-            And(a, b, c) | Or(a, b, c) => *max(a, max(b, c)),
+            And(a, b, c) | Or(a, b, c) | AndNot(a, b, c) => *max(a, max(b, c)),
             Equal(a, b) | Not(a, b) => *max(a, b),
             FixNeg(a) | FixPos(a) => *a,
             EvenXor(vars) | OddXor(vars) | NotAllNeg(vars) | NotAllPos(vars) | AtLeast(_, vars) => {
@@ -76,6 +78,15 @@ impl Clause {
                     CnfClause::new(vec![Neg(a), Neg(b), Pos(c)]),
                 ]
             }
+            AndNot(a, b, c) => {
+                let (a, b, c) = (*a, *b, *c);
+                vec![
+                    CnfClause::new(vec![Pos(a), Neg(b), Neg(c)]),
+                    CnfClause::new(vec![Neg(a), Pos(b), Pos(c)]),
+                    CnfClause::new(vec![Pos(a), Pos(b), Neg(c)]),
+                    CnfClause::new(vec![Neg(a), Neg(b), Neg(c)]),
+                ]
+            }
             Equal(a, b) => {
                 let (a, b) = (*a, *b);
                 vec![
