@@ -78,7 +78,7 @@ mod test {
     use super::*;
     use crate::cnf::CnfClause;
     use crate::cnf::CnfVariable::{Neg, Pos};
-    use Clause::{And, AtLeast, Equal, EvenXor, OddXor, Or};
+    use Clause::{And, AtLeast, Equal, EvenXor, OddXor, Or, AndNot};
 
     #[test]
     fn single_even_xor() {
@@ -110,6 +110,18 @@ mod test {
         assert_eq!(sat.to_cnf(), expected_cnf);
     }
 
+    #[test]
+    fn single_and_not() {
+        let mut sat = SparseSat::new();
+        sat.insert(AndNot(0, 1, 2));
+        let expected_cnf = CnfFormula::with_variables(3)
+            .insert(CnfClause::new(vec![Pos(0), Neg(1), Neg(2)]))
+            .insert(CnfClause::new(vec![Neg(0), Pos(1), Pos(2)]))
+            .insert(CnfClause::new(vec![Pos(0), Pos(1), Neg(2)]))
+            .insert(CnfClause::new(vec![Neg(0), Neg(1), Neg(2)]));
+        assert_eq!(sat.to_cnf(), expected_cnf);
+    }
+
     #[test]
     fn single_or() {
         let mut sat = SparseSat::new();
